@@ -30,17 +30,17 @@
 #include <gtk/gtk.h>
 #include <X11/XF86keysym.h>
 
-#include <libhal-gmanager.h>
-#include <libhal-gdevice.h>
-#include <libhal-gdevicestore.h>
+#ifdef HAVE_LEGACY_BUTTONS
+ #include <hal-manager.h>
+ #include <hal-device.h>
+ #include <hal-device-store.h>
+#endif
 
 #include "gpm-common.h"
 #include "gpm-button.h"
 #include "egg-debug.h"
 #include "gpm-marshal.h"
 
-static void     gpm_button_class_init (GpmButtonClass *klass);
-static void     gpm_button_init       (GpmButton      *button);
 static void     gpm_button_finalize   (GObject	      *object);
 
 #define GPM_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BUTTON, GpmButtonPrivate))
@@ -53,8 +53,10 @@ struct GpmButtonPrivate
 	gchar			*last_button;
 	GTimer			*timer;
 	gboolean		 lid_is_closed;
-	HalGManager		*hal_manager; /* remove when input events is in the kernel */
-	HalGDevicestore		*hal_devicestore;
+#ifdef HAVE_LEGACY_BUTTONS
+	HalManager		*hal_manager; /* remove when input events is in the kernel */
+	HalDeviceStore		*hal_device_store;
+#endif
 };
 
 enum {
@@ -67,15 +69,14 @@ static gpointer gpm_button_object = NULL;
 
 G_DEFINE_TYPE (GpmButton, gpm_button, G_TYPE_OBJECT)
 
-#define GPM_BUTTON_DUPLICATE_TIMEOUT	0.25f
+#define GPM_BUTTON_DUPLICATE_TIMEOUT	0.125f
 
 /**
  * gpm_button_emit_type:
  **/
-gboolean
+static gboolean
 gpm_button_emit_type (GpmButton *button, const gchar *type)
 {
-	g_return_val_if_fail (button != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
 
 	/* did we just have this button before the timeout? */
@@ -197,7 +198,7 @@ gpm_button_grab_keystring (GpmButton *button, guint64 keycode)
  * Return value: TRUE if we parsed and grabbed okay
  **/
 static gboolean
-gpm_button_xevent_key (GpmButton *button, guint keysym, const gchar *hal_key)
+gpm_button_xevent_key (GpmButton *button, guint keysym, const gchar *key_name)
 {
 	gchar *key = NULL;
 	gboolean ret;
@@ -229,7 +230,7 @@ gpm_button_xevent_key (GpmButton *button, guint keysym, const gchar *hal_key)
 	}
 
 	/* add to hash table */
-	g_hash_table_insert (button->priv->keysym_to_name_hash, (gpointer) keycode_str, (gpointer) g_strdup (hal_key));
+	g_hash_table_insert (button->priv->keysym_to_name_hash, (gpointer) keycode_str, (gpointer) g_strdup (key_name));
 
 	/* the key is freed in the hash function unref */
 	return TRUE;
@@ -262,7 +263,6 @@ gpm_button_class_init (GpmButtonClass *klass)
 gboolean
 gpm_button_is_lid_closed (GpmButton *button)
 {
-	g_return_val_if_fail (button != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
 	return button->priv->lid_is_closed;
 }
@@ -281,6 +281,7 @@ gpm_button_reset_time (GpmButton *button)
 	return TRUE;
 }
 
+#ifdef HAVE_LEGACY_BUTTONS
 /**
  * emit_button_pressed:
  *
@@ -298,7 +299,7 @@ gpm_button_reset_time (GpmButton *button)
  *      button.type=""
  */
 static void
-emit_button_pressed (GpmButton *button, HalGDevice *device, const gchar *details)
+emit_button_pressed (GpmButton *button, HalDevice *device, const gchar *details)
 {
 	gchar *type = NULL;
 	gboolean state;
@@ -309,10 +310,10 @@ emit_button_pressed (GpmButton *button, HalGDevice *device, const gchar *details
 
 	if (strcmp (details, "") == 0) {
 		/* no details about the event, so we get more info for type 1 buttons */
-		hal_gdevice_get_string (device, "button.type", &type, NULL);
+		hal_device_get_string (device, "button.type", &type, NULL);
 		/* hal may no longer be there */
 		if (type == NULL) {
-			egg_warning ("cannot get button type for %s", hal_gdevice_get_udi (device));
+			egg_warning ("cannot get button type for %s", hal_device_get_udi (device));
 			goto out;
 		}
 	} else {
@@ -324,7 +325,7 @@ emit_button_pressed (GpmButton *button, HalGDevice *device, const gchar *details
 	state = TRUE;
 	/* we need to get the button state for lid buttons */
 	if (strcmp (type, "lid") == 0)
-		hal_gdevice_get_bool (device, "button.state.value", &state, NULL);
+		hal_device_get_bool (device, "button.state.value", &state, NULL);
 
 	/* abstact away that HAL has an extra parameter */
 	if (strcmp (type, GPM_BUTTON_LID_DEP) == 0 && state == FALSE)
@@ -366,7 +367,7 @@ out:
  * changed, and we have we have subscribed to changes for that device.
  */
 static void
-hal_device_property_modified_cb (HalGDevice    *device,
+hal_device_property_modified_cb (HalDevice    *device,
 				 const gchar   *key,
 				 gboolean       is_added,
 				 gboolean       is_removed,
@@ -382,7 +383,7 @@ hal_device_property_modified_cb (HalGDevice    *device,
 
 	/* only match button* values */
 	if (strncmp (key, "button", 6) == 0) {
-		egg_debug ("state of a button has changed : %s, %s", hal_gdevice_get_udi (device), key);
+		egg_debug ("state of a button has changed : %s, %s", hal_device_get_udi (device), key);
 		emit_button_pressed (button, device, "");
 	}
 }
@@ -398,7 +399,7 @@ hal_device_property_modified_cb (HalGDevice    *device,
  * changed, and we have we have subscribed to changes for that device.
  */
 static void
-hal_device_condition_cb (HalGDevice    *device,
+hal_device_condition_cb (HalDevice    *device,
 			 const gchar   *condition,
 			 const gchar   *details,
 			 GpmButton     *button)
@@ -418,20 +419,20 @@ static void
 watch_add_button (GpmButton *button,
 		  const gchar   *udi)
 {
-	HalGDevice *device;
+	HalDevice *device;
 
-	device = hal_gdevice_new ();
-	hal_gdevice_set_udi (device, udi);
-	hal_gdevice_watch_condition (device);
-	hal_gdevice_watch_property_modified (device);
+	device = hal_device_new ();
+	hal_device_set_udi (device, udi);
+	hal_device_watch_condition (device);
+	hal_device_watch_property_modified (device);
 
 	g_signal_connect (device, "property-modified",
 			  G_CALLBACK (hal_device_property_modified_cb), button);
 	g_signal_connect (device, "device-condition",
 			  G_CALLBACK (hal_device_condition_cb), button);
 
-	/* when added to the devicestore, devices are automatically unref'ed */
-	hal_gdevicestore_insert (button->priv->hal_devicestore, device);
+	/* when added to the device_store, devices are automatically unref'ed */
+	hal_device_store_insert (button->priv->hal_device_store, device);
 }
 
 /**
@@ -447,7 +448,7 @@ coldplug_buttons (GpmButton *button)
 
 	/* devices of type button */
 	error = NULL;
-	ret = hal_gmanager_find_capability (button->priv->hal_manager, "button", &device_names, &error);
+	ret = hal_manager_find_capability (button->priv->hal_manager, "button", &device_names, &error);
 	if (!ret) {
 		egg_warning ("Couldn't obtain list of buttons: %s", error->message);
 		g_error_free (error);
@@ -463,19 +464,19 @@ coldplug_buttons (GpmButton *button)
 		egg_debug ("Couldn't obtain list of buttons");
 	}
 
-	hal_gmanager_free_capability (device_names);
+	hal_manager_free_capability (device_names);
 }
 
 /**
  * hal_daemon_start_cb:
  **/
 static void
-hal_daemon_start_cb (HalGManager *hal_manager,
+hal_daemon_start_cb (HalManager *hal_manager,
 		     GpmButton   *button)
 {
 	/* get new devices, hal has come back up */
-	if (button->priv->hal_devicestore == NULL) {
-		button->priv->hal_devicestore = hal_gdevicestore_new ();
+	if (button->priv->hal_device_store == NULL) {
+		button->priv->hal_device_store = hal_device_store_new ();
 		coldplug_buttons (button);
 	}
 }
@@ -484,15 +485,16 @@ hal_daemon_start_cb (HalGManager *hal_manager,
  * hal_daemon_stop_cb:
  **/
 static void
-hal_daemon_stop_cb (HalGManager *hal_manager,
+hal_daemon_stop_cb (HalManager *hal_manager,
 		    GpmButton   *button)
 {
 	/* clear devices, HAL is going down */
-	if (button->priv->hal_devicestore != NULL) {
-		g_object_unref (button->priv->hal_devicestore);
-		button->priv->hal_devicestore = NULL;
+	if (button->priv->hal_device_store != NULL) {
+		g_object_unref (button->priv->hal_device_store);
+		button->priv->hal_device_store = NULL;
 	}
 }
+#endif
 
 /**
  * gpm_button_init:
@@ -501,8 +503,6 @@ hal_daemon_stop_cb (HalGManager *hal_manager,
 static void
 gpm_button_init (GpmButton *button)
 {
-	gboolean have_xevents = FALSE;
-
 	button->priv = GPM_BUTTON_GET_PRIVATE (button);
 
 	button->priv->screen = gdk_screen_get_default ();
@@ -514,39 +514,40 @@ gpm_button_init (GpmButton *button)
 
 	button->priv->lid_is_closed = FALSE;
 
-#ifdef HAVE_XEVENTS
-	have_xevents = TRUE;
+	/* register the brightness keys */
+	gpm_button_xevent_key (button, XF86XK_PowerOff, GPM_BUTTON_POWER);
+#ifdef HAVE_XF86XK_SUSPEND
+	gpm_button_xevent_key (button, XF86XK_Suspend, GPM_BUTTON_SUSPEND);
 #endif
+	gpm_button_xevent_key (button, XF86XK_Sleep, GPM_BUTTON_SUSPEND); /* should be configurable */
+#ifdef HAVE_XF86XK_HIBERNATE
+	gpm_button_xevent_key (button, XF86XK_Hibernate, GPM_BUTTON_HIBERNATE);
+#endif
+	gpm_button_xevent_key (button, XF86XK_MonBrightnessUp, GPM_BUTTON_BRIGHT_UP);
+	gpm_button_xevent_key (button, XF86XK_MonBrightnessDown, GPM_BUTTON_BRIGHT_DOWN);
+	gpm_button_xevent_key (button, XF86XK_ScreenSaver, GPM_BUTTON_LOCK);
+#ifdef HAVE_XF86XK_BATTERY
+	gpm_button_xevent_key (button, XF86XK_Battery, GPM_BUTTON_BATTERY);
+#endif
+	gpm_button_xevent_key (button, XF86XK_KbdBrightnessUp, GPM_BUTTON_KBD_BRIGHT_UP);
+	gpm_button_xevent_key (button, XF86XK_KbdBrightnessDown, GPM_BUTTON_KBD_BRIGHT_DOWN);
+	gpm_button_xevent_key (button, XF86XK_KbdLightOnOff, GPM_BUTTON_KBD_BRIGHT_TOGGLE);
 
-	if (have_xevents) {
-		/* register the brightness keys */
-		gpm_button_xevent_key (button, XF86XK_PowerOff, GPM_BUTTON_POWER);
-//		gpm_button_xevent_key (button, XF86XK_Suspend, GPM_BUTTON_SUSPEND);
-		gpm_button_xevent_key (button, XF86XK_Sleep, GPM_BUTTON_SUSPEND); /* should be configurable */
-//		gpm_button_xevent_key (button, XF86XK_Hibernate, GPM_BUTTON_HIBERNATE);
-		gpm_button_xevent_key (button, XF86XK_MonBrightnessUp, GPM_BUTTON_BRIGHT_UP);
-		gpm_button_xevent_key (button, XF86XK_MonBrightnessDown, GPM_BUTTON_BRIGHT_DOWN);
-		gpm_button_xevent_key (button, XF86XK_ScreenSaver, GPM_BUTTON_LOCK);
-//		gpm_button_xevent_key (button, XF86XK_Battery, GPM_BUTTON_BATTERY);
-		gpm_button_xevent_key (button, XF86XK_KbdBrightnessUp, GPM_BUTTON_KBD_BRIGHT_UP);
-		gpm_button_xevent_key (button, XF86XK_KbdBrightnessDown, GPM_BUTTON_KBD_BRIGHT_DOWN);
-		gpm_button_xevent_key (button, XF86XK_KbdLightOnOff, GPM_BUTTON_KBD_BRIGHT_TOGGLE);
-
-		/* use global filter */
-		gdk_window_add_filter (button->priv->window,
-				       gpm_button_filter_x_events, (gpointer) button);
-	}
+	/* use global filter */
+	gdk_window_add_filter (button->priv->window,
+			       gpm_button_filter_x_events, (gpointer) button);
 
+#ifdef HAVE_LEGACY_BUTTONS
 	/* remove when button support is out of HAL */
-	button->priv->hal_manager = hal_gmanager_new ();
+	button->priv->hal_manager = hal_manager_new ();
 	g_signal_connect (button->priv->hal_manager, "daemon-start",
 			  G_CALLBACK (hal_daemon_start_cb), button);
 	g_signal_connect (button->priv->hal_manager, "daemon-stop",
 			  G_CALLBACK (hal_daemon_stop_cb), button);
-
-	button->priv->hal_devicestore = hal_gdevicestore_new ();
+	button->priv->hal_device_store = hal_device_store_new ();
 
 	coldplug_buttons (button);
+#endif
 }
 
 /**
@@ -563,8 +564,10 @@ gpm_button_finalize (GObject *object)
 	button = GPM_BUTTON (object);
 	button->priv = GPM_BUTTON_GET_PRIVATE (button);
 
+#ifdef HAVE_LEGACY_BUTTONS
 	g_object_unref (button->priv->hal_manager);
-	g_object_unref (button->priv->hal_devicestore);
+	g_object_unref (button->priv->hal_device_store);
+#endif
 	g_free (button->priv->last_button);
 	g_timer_destroy (button->priv->timer);
 
